@@ -22,6 +22,14 @@ extern void gck_marshal_VOID__STRING_ULONG (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
+/* VOID:OBJECT,ULONG (gck-marshal.list:3) */
+extern void gck_marshal_VOID__OBJECT_ULONG (GClosure     *closure,
+                                            GValue       *return_value,
+                                            guint         n_param_values,
+                                            const GValue *param_values,
+                                            gpointer      invocation_hint,
+                                            gpointer      marshal_data);
+
 G_END_DECLS
 
 #endif /* __gck_marshal_MARSHAL_H__ */
